@@ -156,7 +156,7 @@ class FtpSimple:
       self.af = self.sock.family
       self.file = self.sock.makefile('r', encoding=self.ENCODING)
       logging.debug(f"[WELCOME] {self._getresp()}")
-      logging.info("[=] connected")
+      logging.debug("[=] connected")
       return True
     raise Error("Remote host not defined")
 
@@ -166,7 +166,7 @@ class FtpSimple:
       resp = self.sendcmd(f"PASS {self.password}")
     if resp[0] != '2':
       raise ErrorReply(resp)
-    logging.info("[=] Logged in")
+    logging.debug("[=] Logged in")
     return resp
 
   def _putline(self, line):
@@ -515,7 +515,7 @@ class Ftps(FtpSimple):
                                            server_hostname=self.hostname)
       self.file = self.sock.makefile('r', encoding=self.ENCODING)
       logging.debug(f"[WELCOME] {self._getresp()}")
-      logging.info("[=] connected")
+      logging.debug("[=] connected")
       return True
     raise Error("Remote host not defined")
 
@@ -656,7 +656,7 @@ class Ftpes(Ftps):
       self.file = self.sock.makefile('r', encoding=self.ENCODING)
       logging.debug(f"[WELCOME] {self._getresp()}")
       self.auth()
-      logging.info("[=] connected")
+      logging.debug("[=] connected")
       return True
     raise Error("Remote host not defined")
 
