@@ -73,54 +73,53 @@ class Ssh:
     - La clef SSH n'a pas été trouvée
     - ...
     """
-    logging.info(f"[+] Connexion a {self.username}@{self.hostname}:{self.port}")
+    logging.debug(f"[+] Connecting to {self.username}@{self.hostname}:{self.port}")
     try:
       self.remote = paramiko.SSHClient()
       self.remote.set_missing_host_key_policy(paramiko.AutoAddPolicy())
       self.remote.load_system_host_keys()
       if self.key_filename:
-        logging.debug(f"Utilisation de la clef: {self.key_filename}")
+        logging.debug(f"Using key: {self.key_filename}")
         pkey = paramiko.RSAKey.from_private_key_file(self.key_filename, password=self.password)
-        logging.debug("Connexion")
+        logging.debug("Connection")
         self.remote.connect(hostname=self.hostname,
                             port=self.port,
                             username=self.username,
                             pkey=pkey)
       elif self.password:
-        logging.debug(f"Utilisation du mot de passe: {self.password}")
+        logging.debug(f"Using password: {self.password}")
         self.remote.connect(hostname=self.hostname,
                             port=self.port,
                             username=self.username,
                             password=self.password)
       else:
-        logging.debug("Utilisation de la clef SSH par defaut")
+        logging.debug("Using default SSH key")
         self.remote.connect(hostname=self.hostname,
                             port=self.port,
                             username=self.username)
     except paramiko.BadHostKeyException as err:
-      err_msg = f"La clef de l'hote distant n'est pas celle attendue: [{err.__class__.__name__}] {err}"
+      err_msg = f"Bad SSH Host Key : [{err.__class__.__name__}] {err}"
       logging.critical(f" '-> {err_msg}")
       raise ScrippyRemoteError(err_msg) from err
     except paramiko.AuthenticationException as err:
-      err_msg = f"Echec de l'authentification: [{err.__class__.__name__}] {err}"
+      err_msg = f"Failed to authenticate: [{err.__class__.__name__}] {err}"
       logging.critical(f" '-> {err_msg}")
       raise ScrippyRemoteError(err_msg) from err
     except (paramiko.SSHException,
             socket.gaierror,
             paramiko.ssh_exception.NoValidConnectionsError,
             FileNotFoundError) as err:
-      err_msg = f"Echec de la connexion: [{err.__class__.__name__}] {err}"
+      err_msg = f"Connection error: [{err.__class__.__name__}] {err}"
       logging.critical(f" '-> {err_msg}")
       raise ScrippyRemoteError(err_msg) from err
     except Exception as err:
-      err_msg = f"Erreur inattendue: [{err.__class__.__name__}] {err}"
+      err_msg = f"Unexpected error: [{err.__class__.__name__}] {err}"
       logging.critical(f" +-> {err_msg}")
-      logging.critical(" '-> Merci de reporter l'erreur ci-dessus afin qu'elle soit integree au module scrippy_remote.")
       raise ScrippyRemoteError(err_msg) from err
 
   def close(self):
     """ Ferme la connexion passée en argument. """
-    logging.info(f"[+] Fermeture de la connexion a {self.username}@{self.hostname}")
+    logging.debug(f"[+] Closing connection to {self.username}@{self.hostname}")
     if self.remote:
       self.remote.close()
 
@@ -142,8 +141,7 @@ class Ssh:
 
     :raises: `SystemExit` -- if the server fails to execute the command
     """
-    logging.info("[+] Execution de la commande (Utiliser --debug pour voir la commande)")
-    logging.debug(f" '-> {command}")
+    logging.debug(f"[+] Running command: {command}")
     try:
       exit_code = None
       stdin, stdout, stderr = self.remote.exec_command(command, **kwargs)
@@ -153,7 +151,7 @@ class Ssh:
         sleep(0.1)
         while channel.recv_ready():
           line = stdout.readline().strip()
-          _log_line(line, log_stdout, logging.INFO)
+          _log_line(line, log_stdout, logging.DEBUG)
           if return_stdout:
             stdout_content.append(line)
         while channel.recv_stderr_ready():
@@ -164,7 +162,7 @@ class Ssh:
           # Read last lines
           for line in stdout:
             line = line.strip()
-            _log_line(line, log_stdout, logging.INFO)
+            _log_line(line, log_stdout, logging.DEBUG)
             if return_stdout:
               stdout_content.append(line)
           for line in stderr:
@@ -178,7 +176,7 @@ class Ssh:
         res['stdout'] = stdout_content
       return res
     except paramiko.SSHException as err:
-      err_msg = f"Erreur lors de l'execution de la commande: [{err.__class__.__name__}] {err}"
+      err_msg = f"Error while running command: [{err.__class__.__name__}] {err}"
       logging.critical(err_msg)
       raise ScrippyRemoteError(err_msg) from err
 
@@ -226,23 +224,23 @@ class Ssh:
       if num_err == 0 and delete:
         self.delete_local_files(files, exit_on_error)
       elif delete:
-        logging.error(f"[+] Nombre d'erreur(s) rencontree(s): {num_err}")
-        logging.error(" '-> Suppression des fichiers locaux annulee")
+        logging.error(f"[+] Encountered errors: {num_err}")
+        logging.error(" '-> File deletion aborted")
       return num_err
     except Exception as err:
-      msg = "Erreur irrecuperable"
+      msg = "Unrecoverable error"
       if exit_on_error:
-        msg = "exit_on_error positionne à True"
-      logging.error(f"[{err.__class__.__name__}] {err}: Arret du traitement")
-      logging.error(f" '-> {msg}: Arret du traitement")
+        msg = "exit_on_error is set to True"
+      logging.error(f"[{err.__class__.__name__}] {err}: Stopping execution")
+      logging.error(f" '-> {msg}: Stopping execution")
       if num_err == 0:
         num_err += 1
       return num_err
 
   def find_local_files(self, local_path, pattern, recursive):
-    logging.info("[+] Recuperation de la liste des fichiers locaux")
-    logging.debug(f" '-> Repertoire local: {local_path}")
-    logging.debug(f" '-> Motif: {pattern}")
+    logging.debug("[+] Getting local files list")
+    logging.debug(f" '-> Local folder: {local_path}")
+    logging.debug(f" '-> Pattern: {pattern}")
     regex = re.compile(pattern)
     local_files = []
     local_dirs = []
@@ -262,11 +260,11 @@ class Ssh:
   def transfer_local_files(self, local_files, remote_path, exit_on_error):
     num_err = 0
     sftp = self.remote.open_sftp()
-    logging.info(f"[+] Transfert des fichiers vers {self.username}@{self.hostname}:{self.port}:{remote_path}")
+    logging.debug(f"[+] File transfert to {self.username}@{self.hostname}:{self.port}:{remote_path}")
     if len(local_files) == 0:
-      logging.info(" '-> Aucun fichier")
+      logging.debug(" '-> No file found")
     for local_file in local_files:
-      logging.info(f" '-> {local_file}")
+      logging.debug(f" '-> {local_file}")
       remote_fname = os.path.join(remote_path, os.path.basename(local_file))
       try:
         sftp.put(local_file, remote_fname, confirm=True)
@@ -274,25 +272,25 @@ class Ssh:
         num_err += 1
         logging.warning(f"  '-> [{err.__class__.__name__}] {err}")
         if exit_on_error:
-          err_msg = "Erreur lors du transfert et exit_on_error positionnee a True: Arret immediat."
+          err_msg = "Transfert error and exit_on_error is set to True: Immediate abortion."
           logging.critical(err_msg)
           raise ScrippyRemoteError(err_msg) from err
     return num_err
 
   def delete_local_files(self, local_files, exit_on_error):
     num_err = 0
-    logging.info("[+] Suppression des fichiers locaux")
+    logging.debug("[+] Local files deletion")
     if len(local_files) == 0:
-      logging.info(" '-> Aucun fichier")
+      logging.debug(" '-> No file found")
     for local_file in local_files:
-      logging.info(f" '-> {local_file}")
+      logging.debug(f" '-> {local_file}")
       try:
         os.remove(local_file)
       except Exception as err:
         num_err += 1
         logging.warning(f"  '-> [{err.__class__.__name__}] {err}")
         if exit_on_error:
-          err_msg = "Erreur lors de la suppression et exit_on_error positionnee a True: Arret immediat."
+          err_msg = "Error while deleting and exit_on_error is set to True: Immediate abortion."
           logging.critical(err_msg)
           raise ScrippyRemoteError(err_msg) from err
     return num_err
@@ -332,17 +330,17 @@ class Ssh:
     if delete and err == 0:
       err += self.delete_remote_files(remote_files, exit_on_error)
     elif delete:
-      logging.error(f"[+] Nombre d'erreur(s) rencontree(s): {err}")
-      logging.error(" '-> Suppression des fichiers distants annulee")
+      logging.error(f"[+] Encountered errors: {err}")
+      logging.error(" '-> File deletion aborted")
     return err
 
   def find_remote_files(self, remote_path, pattern, recursive, exit_on_error, sftp=None):
     if sftp is None:
       sftp = self.remote.open_sftp()
 
-    logging.debug("[+] Recuperation de la liste des fichiers distants")
-    logging.debug(f" '-> Repertoire distant: {remote_path}")
-    logging.debug(f" '-> Motif: {pattern}")
+    logging.debug("[+] Getting remote files list")
+    logging.debug(f" '-> Remote folder: {remote_path}")
+    logging.debug(f" '-> Pattern: {pattern}")
     regex = re.compile(pattern)
     remote_files = []
     remote_dirs = []
@@ -359,10 +357,10 @@ class Ssh:
         for directory in remote_dirs:
           remote_files += self.find_remote_files(directory, pattern, recursive, exit_on_error, sftp)
     except Exception as err:
-      err_msg = f"Erreur lors de recuperation: [{err.__class__.__name__}] {err}"
+      err_msg = f"Error while getting file list: [{err.__class__.__name__}] {err}"
       logging.warning(err_msg)
       if exit_on_error:
-        err_msg = "Erreur lors de la recuperation de la liste des fichiers et exit_on_error positionnee a True: Arret immediat."
+        err_msg = "Error while getting file list and exit_on_error set to True: Immediate abortion."
         logging.critical(err_msg)
         raise ScrippyRemoteError(err_msg) from err
     return remote_files
@@ -370,13 +368,13 @@ class Ssh:
   def transfer_remote_files(self, local_path, remote_files, exit_on_error):
     num_err = 0
     sftp = self.remote.open_sftp()
-    logging.info(f"[+] Transfert des fichiers depuis {self.username}@{self.hostname}:{self.port}")
+    logging.debug(f"[+] File transfert from {self.username}@{self.hostname}:{self.port}")
     if len(remote_files) == 0:
-      logging.info(" '-> Aucun fichier")
+      logging.debug(" '-> No file found")
     for remote_file in remote_files:
       local_fname = os.path.basename(remote_file)
       local_fname = os.path.join(local_path, local_fname)
-      logging.info(f" '-> {remote_file}")
+      logging.debug(f" '-> {remote_file}")
       logging.debug(f" '-> {local_fname}")
       try:
         sftp.get(remote_file, local_fname)
@@ -385,7 +383,7 @@ class Ssh:
         err_msg = f"[{err.__class__.__name__}] {err}"
         logging.warning(err_msg)
         if exit_on_error:
-          err_msg = "Erreur lors du transfert et exit_on_error positionnee a True: Arret immediat."
+          err_msg = "Error while transfering and exit_on_error set to True: Immediate abortion."
           logging.critical(err_msg)
           raise ScrippyRemoteError(err_msg) from err
     return num_err
@@ -393,19 +391,19 @@ class Ssh:
   def delete_remote_files(self, remote_files, exit_on_error):
     num_err = 0
     sftp = self.remote.open_sftp()
-    logging.info("[+] Suppression des fichiers distants")
+    logging.debug("[+] Remote files deletion")
     if len(remote_files) == 0:
-      logging.info(" '-> Aucun fichier")
+      logging.debug(" '-> No file found")
     for remote_file in remote_files:
       try:
-        logging.info(f" '-> {remote_file}")
+        logging.debug(f" '-> {remote_file}")
         sftp.remove(remote_file)
       except Exception as err:
         num_err += 1
         err_msg = f"[{err.__class__.__name__}] {err}"
         logging.warning(err_msg)
         if exit_on_error:
-          err_msg = "Erreur lors de la suppression et exit_on_error positionnee a True: Arret immediat."
+          err_msg = "Error while deleting and exit_on_error set to True: Immediate abortion."
           logging.critical(err_msg)
           raise ScrippyRemoteError(err_msg) from err
     return num_err
